@@ -2,7 +2,7 @@ from common.rest_extend.response import RESTResponse, Results, FORBID_CODE
 from django.utils.deprecation import MiddlewareMixin
 from tenant_auth.models import AuthTenant, AuthTenantRole, AuthPermission, AuthRolePermissions
 
-IGNORE_SOURCE = ['/', '/tenant/permissions/']
+IGNORE_SOURCE = ["/"]
 
 
 class AuthMiddleware(MiddlewareMixin):
@@ -27,17 +27,17 @@ class AuthMiddleware(MiddlewareMixin):
         path = request.path
         tenant = AuthTenant.objects.filter(account=account).first()
         if tenant:
-            if tenant.account == 'admin':
+            if tenant.account == "admin":
                 return True
             # permission = AuthPermission.objects.filter(action=method, source_id=path).first()
             permission = AuthPermission.objects.filter(source_id=path).first()
             if permission:
-                role_permissions = AuthRolePermissions.objects.filter(permission_id=permission.name).first()
-                if role_permissions:
-                    tenant_role = AuthTenantRole.objects.filter(
-                        role_id=role_permissions.role_id, tenant_id=account
+                tenant_role = AuthTenantRole.objects.filter(tenant_id=account).first()
+                if tenant_role:
+                    role_permissions = AuthRolePermissions.objects.filter(
+                        role_id=tenant_role.role_id, permission_id=permission.name
                     ).first()
-                    if tenant_role:
+                    if role_permissions:
                         return True
 
         return False
