@@ -1,5 +1,7 @@
 from dataclasses import asdict
 
+from django.http import JsonResponse
+
 from common.rest_extend.response import Results, get_error_status_code, RESTResponse
 
 
@@ -60,12 +62,14 @@ def view_decorator(function):
 
 
 def relevance_vaild_legal_decorator(func):
-    def wrapper(obj, request, *args, **kwargs):
+    def wrapper(request, *args, **kwargs):
+        if request.method != "GET" and request.method != "POST":
+            return JsonResponse({"detail": f'Method "{request.method}" not allowed.'}, status=405)
         group = request.GET.get("group")
         if group:
             results = Results()
             results.describe = "此接口不支持参数 'group'！！！"
             return RESTResponse(results)
-        return func(obj, request, *args, **kwargs)
+        return func(request, *args, **kwargs)
 
     return wrapper
