@@ -77,21 +77,6 @@ class Select(BaseArgsParsing, metaclass=abc.ABCMeta):
 
         return orm_q
 
-    def get_page_and_size(self, data):
-        """
-        获取页面和条数
-        :param data:
-        :return:
-        """
-        try:
-            page = int(data.get(self.PAGE, 1))
-            size = int(data.get(self.SIZE, 20))
-            if data.get(self.PAGESIZE):
-                size = int(data.get(self.PAGESIZE))
-        except ValueError as e:
-            raise ValueError(f"'{self.PAGE}' or '{self.SIZE}' must be int")
-        return page, size
-
     def get_page_type_results(self, result, total, page, size, *args, **kwargs):
         """
         获取当前页面结果集
@@ -404,6 +389,57 @@ class BaseJoinView(APIView, Select):
             results.data.result = result
         return RESTResponse(results)
 
+    def post(self, request, obj, obj_serializer, obj_relevance: list = None, m_to_m_obj: list = None,
+             mapping=None,
+             m_to_m_mapping=None):
+        results = Results()
+
+        data = request.data
+        if data.get('data'):
+            data = data.get('data')
+        serializer = obj_serializer(data=data)
+        if obj_relevance and mapping:
+            for obj in obj_relevance:
+                obj_name = obj.__name__.lower()
+                obj_mapping = mapping.get(obj_name)
+                if not obj_mapping:
+                    raise Exception(f'{obj_name}  are not mapping!!!')
+                queryset = self.get_relevance_queryset(obj, obj_name, data)
+                self.extend_relevance_data(data, queryset, obj_mapping)
+        if m_to_m_obj and m_to_m_mapping:
+            for obj in m_to_m_obj:
+                pass
+        try:
+            valid = serializer.is_valid(raise_exception=True)
+            serializer.save()
+            results.describe = "add  successfully！！！"
+            results.status = SUCCESS
+            results.code = 200
+        except Exception as e:
+            results.code, results.describe = get_error_status_code(e)
+
+        return RESTResponse(results)
+
+    def extend_relevance_data(self, data, queryset, obj_mapping):
+        if queryset:
+            value = getattr(queryset, obj_mapping[0], None)
+            if value is not None:
+                data[obj_mapping[1]] = value
+
+    def get_relevance_orm_q(self, obj_name, data):
+        conditions = {}
+        for item, value in data.items():
+            if obj_name + '__' in item:
+                conditions[item.replace(obj_name + '__', '')] = value
+        if conditions:
+            orm_q = self.get_orm_q(conditions)
+            return orm_q
+
+    def get_relevance_queryset(self, obj, obj_name, data):
+        orm_q = self.get_relevance_orm_q(obj_name, data)
+        queryset = obj.objects.filter(orm_q).first()
+        return queryset
+
     def extend_result_field(self, obj_serializer, obj_relevance, m_to_m_obj, mapping, m_to_m_mapping, queryset):
         """
         扩展字段
