@@ -17,7 +17,7 @@ class BaseArgsParsing:
     RESERVED_FIELD = [PAGE, SIZE, PAGESIZE, SORT]
     SUFFIX_KEYWORD = [LIKE, NOT, IN, LT, GT, LTE, GTE]
 
-    def get_page_and_size(self, data):
+    def get_page_and_size(self, data, max_page=500, max_size=1000, max_total=10000):
         """
         获取页面和条数
         :param data:
@@ -26,10 +26,18 @@ class BaseArgsParsing:
         try:
             page = int(data.get(self.PAGE, 1))
             size = int(data.get(self.SIZE, 20))
-            if data.get(self.PAGESIZE):
-                size = int(data.get(self.PAGESIZE))
-        except ValueError as e:
+        except Exception as e:
             raise ValueError(f"'{self.PAGE}' or '{self.SIZE}' must be int")
+
+        if page * size > max_total:
+            raise ValueError(
+                f"page*size has to be less than max_total,page='{page}',size='{size}',max_total={max_total}"
+            )
+        if data.get(self.PAGESIZE):
+            size = int(data.get(self.PAGESIZE))
+        page = page if page < max_page else max_page
+        size = size if size < max_size else max_size
+
         return page, size
 
     def get_sort(self, data, default_field=None, default_sort=None):
