@@ -7,4 +7,4 @@ class TenantSerializer(serializers.ModelSerializer):
     class Meta:
         model = AuthTenant
         # fields = '__all__'
-        exclude = ('password',)
+        exclude = ("password",)
